
Attitude Representations
========================

An attitude describes the orientation of a frame with respect to a reference
frame.

Common attitude representations include Rotation Matrices, Euler angles,
Euler-Rodrigues, Gibb's vectors quaternions, and more.

Two main representations are considered:

.. toctree::
   :titlesonly:
   :maxdepth: 2

   quaternion/quaternion
   dcm

From which, the following classes are available

.. toctree::
   :titlesonly:
   :maxdepth: 1

   dcm/classDCM
   quaternion/classQuaternion
   quaternion/classQuaternionArray

Several specialized functions are available to transform, and re-define
rotations and attitudes. See:

.. toctree::
   :titlesonly:
   :maxdepth: 1

   special/special